@@ -1,7 +1,7 @@
 CAvariants <-
 function(
   Xtable, mj=NULL,mi=NULL, printdims=4,firstaxis=1,lastaxis=2,
-  catype = "CA") { 
+  catype = "CA",digits=4) { 
 if (printdims<1) stop(paste("Attention: number of dims for output must be at least 1\n\n"))
 if (lastaxis<2) stop(paste("Attention: last axis must be at least 2\n\n"))
 if (!any(catype==c("CA","SOCA","DOCA","NSCA","SONSCA","DONSCA"))) stop(paste("Must be CA, DOCA, SOCA, NSCA, SONSCA or DONSCA"))
@@ -34,10 +34,8 @@ if (is.null(mi)){
    mi <- c(1:rows)}
 else 
 mi<-c(mi)  #natural scores for rows
-
-
 maxaxes <- min(rows,cols)-1
-
+r<-maxaxes
 S <- switch(catype, "CA"=cabasic(X),  "SOCA"=socabasic(X,mj),"DOCA"=docabasic(X,mi,mj),"NSCA"=nscabasic(X),"SONSCA"=sonscabasic(X,mj),
 "DONSCA"=donscabasic(X,mi,mj))
 
@@ -45,12 +43,14 @@ S <- switch(catype, "CA"=cabasic(X),  "SOCA"=socabasic(X,mj),"DOCA"=docabasic(X,
 if(catype=="CA"){
 Fmat <- S@RX %*% S@Rweights %*% S@Raxes
 Gmat <- S@CX %*% S@Cweights %*% S@Caxes
-dmum1 <- diag( (S@mu + (S@mu==0)) * (1-(S@mu==0)) )
+#dmum1 <- diag( (S@mu + (S@mu==0)) * (1-(S@mu==0)) )
 Fbi <- S@Cweights %*%  S@Caxes # no orthonormal
 Gbi <-S@Rweights %*%   S@Raxes # no orthonormal
 pcc <- t(S@CX)
 #dimnames(pcc)<-dimnames(X)
-inertia <- (S@mu*S@mu)/n
+tau=NULL
+tauden=NULL
+inertia <- (S@mu[1:r]*S@mu[1:r])
 comps<-diag(inertia)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(Gbi[,firstaxis:lastaxis]))
 Z<-Trend
@@ -67,16 +67,21 @@ if  ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){
 Gmat<-(-1)*Gmat
 Fmat<-(-1)*Fmat
 }
+
 reconstruction<-t(Gmat%*%t(S@Cweights%*%Fbi))
 dimnames(reconstruction)<-dimnames(X)
-inertia <- S@mu/n #number of inertia of row poly
-inertia2<-S@mu2/n #number of inertias of column poly
+inertia <- S@mu[1:r]/n #number of inertia of row poly
+inertia2<-S@mu2[1:r]/n #number of inertias of column poly
 Z1<-S@Z
+tau=NULL
+tauden=NULL
 comps <- compstable.exe(Z1) 
-Icompnames <- c("** Row Components **", "Location", "Dispersion", "Error", "** Column Components **", "Location", "Dispersion", "Error", "** Chi-squared Statistic **")
+Icompnames <- c( "Location", "Dispersion", "Cubic","Error", "** Chi-squared Statistic **")
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("u", 1:(rows - 1),sep=""), paste("v", 1:(cols - 1),sep=""))
-dimnames(comps) <- list(paste(Icompnames), paste(Jcompnames))
+dimnames(comps$compsR) <- list(paste(Icompnames), paste(Jcompnames))
+dimnames(comps$compsC) <- list(paste(Icompnames), paste(Jcompnames))
+
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(S@Rweights%*%Gbi[,firstaxis:lastaxis]))
 #browser()
 }
@@ -90,12 +95,16 @@ Fmat <- S@RX %*% S@Rweights %*% S@Raxes #column principal coordinates
 if ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat}
 Gbi <-S@Raxes
 Fbi <- S@Caxes 
-inertia <- (S@mu*S@mu)/n
-inertia2<-(S@mu2[-1])/n
+inertia <- (S@mu[1:r]^2)/n
+inertia2<-(S@mu2[1:r])/n
+#inertia2<-(S@mu2[-1])/n
 #comps<-diag(inertia2)
+tauden=NULL
+tau=NULL
 Z1<-S@Z
 comps <- compsonetable.exe(Z1) 
-Icompnames <- c( "** Column Components **", "Location", "Dispersion", "Error", "** C-Statistic **")
+#Icompnames <- c( "** Column Components **", "Location", "Dispersion", "Cubic","Error", "** Chi-squared Statistic **")
+Icompnames <- c( "Location", "Dispersion","Cubic", "Error", "** Chi-squared Statistic **")
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("m", 1:nrow(Z),sep="" ), paste("v", 1:(cols - 1),sep=""))
 dimnames(comps) <- list(paste(Icompnames), paste(Jcompnames))
@@ -107,12 +116,15 @@ Trend<-(Fmat[,firstaxis:lastaxis]%*%t(S@Rweights%*%Gbi[,firstaxis:lastaxis]))
 if(catype=="NSCA"){
 Fbi <-  S@Caxes
 Gbi <-   S@Raxes 
-dmum1 <-diag( (S@mu + (S@mu==0)) * (1-(S@mu==0)) )
+#dmum1 <-diag( (S@mu + (S@mu==0)) * (1-(S@mu==0)) )
+dmum1 <-diag( S@mu [1:r])
 pcc<-S@RX
 dimnames(pcc)<-dimnames(X)
-Gmat <-  S@Raxes %*% dmum1
-Fmat <- S@Caxes %*% dmum1
-inertia <- S@mu*S@mu
+Gmat <-  S@Raxes[,1:r] %*% dmum1
+Fmat <- S@Caxes[,1:r] %*% dmum1
+tauden<-S@tauDen
+inertia <- S@mu[1:r]*S@mu[1:r]
+tau<-sum(inertia)/tauden
 comps<-diag(inertia)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(S@Rweights%*%Gbi[,firstaxis:lastaxis]))
 Z<-Trend
@@ -128,15 +140,20 @@ dimnames(pcc)<-dimnames(X)
 Gmat <-  S@CX %*% S@Cweights %*% S@Caxes #row principal coordinates
 Fmat <- S@RX  %*% S@Rweights %*% S@Raxes #column principal coordinates
 if  ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat}
-inertia <- S@mu
-inertia2<-S@mu2 
-Z2<-sqrt((n-1)*(rows-1))*S@Z
+inertia <- S@mu[1:r]
+inertia2<-S@mu2[1:r] 
+tauden<-S@tauDen
+Z2<-1/sqrt(tauden)*sqrt((n-1)*(rows-1))*S@Z
+#Z2<-sqrt((n-1)*(rows-1))*S@Z #when tau
+tau<-sum(inertia)/tauden
 comps <- compstable.exe(Z2) 
-Icompnames <- c("** Row Components **", "Location", "Dispersion", "Error", "** Column Components **", 
-"Location", "Dispersion", "Error", "** Chi-squared Statistic **")
+Icompnames <- c( "Location", "Dispersion","Cubic", "Error", "** C-Statistic **")
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("u", 1:(rows-1 ),sep=""), paste("v", 1:(cols -1),sep=""))
-dimnames(comps) <- list(paste(Icompnames), paste(Jcompnames))
+#dimnames(Z) <- list(paste("u", 1:(rows ),sep=""), paste("v", 1:(cols -1),sep=""))
+dimnames(comps$compsR) <- list(paste(Icompnames), paste(Jcompnames))
+dimnames(comps$compsC) <- list(paste(Icompnames), paste(Jcompnames))
+
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(Gbi[,firstaxis:lastaxis]))
 
 #browser()
@@ -149,15 +166,18 @@ Z<-S@Z
 Gmat <- S@CX %*% S@Cweights %*% S@Caxes #column principal coordinates with principal axes
 Fmat <- S@RX %*% (S@Rweights) %*% S@Raxes #row principal coordinates with polys
 Gbi <- S@Raxes
+#Gbi<-(sqrt(S@Rweights))%*%S@Raxes
 Fbi <- S@Caxes 
 if ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat
 #Fbi<-(-1)*Fbi
 }
-inertia <- S@mu
-inertia2 <- S@mu2
-Z1<-sqrt((n-1)*(rows-1))*S@Z
+inertia <- S@mu[1:r]
+inertia2 <- S@mu2[1:r]
+tauden<-S@tauDen
+tau<-sum(inertia)/tauden
+Z1<-1/sqrt(tauden)*sqrt((n-1)*(rows-1))*S@Z
 comps <- compsonetable.exe(Z1) 
-Icompnames <- c( "** Column Components **", "Location", "Dispersion", "Error", "** C-Statistic **")
+Icompnames <- c( "Location", "Dispersion", "Cubic","Error", "** C-Statistic **")
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("m", 1:nrow(S@Z),sep=""), paste("v", 1:(cols - 1),sep=""))
 dimnames(comps) <- list(paste(Icompnames), paste(Jcompnames))
@@ -170,13 +190,13 @@ Trend<-t(Gmat[,firstaxis:lastaxis]%*%t(Fbi[,firstaxis:lastaxis]))
 # OTHER CALCULATIONS
 
 # Calc inertia sum
-dmum2 <- diag( 1/(inertia + (S@mu==0)) * (1-(S@mu==0)) )
+#dmum2 <- diag( 1/(inertia + (S@mu==0)) * (1-(S@mu==0)) )
 inertiasum <- sum(inertia)
 inertiapc <- 100*inertia/inertiasum
 cuminertiapc <- cumsum(inertiapc)
 inertiapc <- round(100*inertiapc)/100
 cuminertiapc <- round(100*cuminertiapc)/100
-inertias <- round(cbind(inertia,inertiapc,cuminertiapc),digits=3)
+inertias <- round(cbind(inertia,inertiapc,cuminertiapc),digits=digits)
 #browser()
 
 ##########################################################
@@ -186,7 +206,7 @@ inertiapc2 <- 100*inertia2/inertiasum2
 cuminertiapc2 <- cumsum(inertiapc2)
 inertiapc2 <- round(100*inertiapc2)/100
 cuminertiapc2 <- round(100*cuminertiapc2)/100
-inertias2 <- round(cbind(inertia2,inertiapc2,cuminertiapc2),digits=3)
+inertias2 <- round(cbind(inertia2,inertiapc2,cuminertiapc2),digits=digits)
 }
 else inertias2<-inertias
 # Calc contributions and correlations
@@ -198,23 +218,21 @@ else {uni<-rep(1,rows)
 dr<-diag(uni)}
 dc <- diag(colSums(Xstd))
 dimnames(Trend)<-list(rowlabels,collabels)
-
 #############################
-cacorpo<- new("cacorporateplus",S=S,
-DataMatrix=X, rows=rows, cols=cols, 
+#cacorpo<- new("cacorporateplus",S=S,
+#DataMatrix=X, rows=rows, cols=cols, 
+#rowlabels=rowlabels, collabels=collabels,
+#Rprinccoord=Fmat, Cprinccoord=Gmat, Rstdcoord=Fbi, Cstdcoord=Gbi,
+# inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
+#  maxaxes=maxaxes,catype=catype,printdims=printdims,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
+#Trend=Trend,Z=Z)
+
+list(
+DataMatrix=X, rows=rows, cols=cols, r=r,
 rowlabels=rowlabels, collabels=collabels,
-Rprinccoord=Fmat, Cprinccoord=Gmat, Rstdcoord=Fbi, Cstdcoord=Gbi,
+Rprinccoord=Fmat[,1:r], Cprinccoord=Gmat[,1:r], Rstdcoord=Fbi[,1:r], Cstdcoord=Gbi[,1:r],tauden=tauden,tau=tau,
  inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
   maxaxes=maxaxes,catype=catype,printdims=printdims,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
 Trend=Trend,Z=Z)
 
-
-#browser()
-#print.CAvariants(cacorpo,printdims=printdims)
-
-#plot.CAvariants(cacorpo,cex=cex,firstaxis=firstaxis,lastaxis=lastaxis,
-#inert=inertias,inertsum=inertiasum,prop=prop,M=M,catype=catype,
-#biptype=biptype,plottype=plottype,scaleplot=scaleplot,posleg=posleg,pos=pos,ell=ell)
-(list(cacorpo=cacorpo))
-
 }
