@@ -1,7 +1,7 @@
 donscabasic <-
 function (xo,mi,mj) 
 {
-  rmax <- min(dim(xo)) - 1
+#  rmax <- min(dim(xo)) - 1
 x <- xo/sum(xo)
 rsums <- as.vector(rowSums(x))
 csums <- as.vector(colSums(x))
@@ -12,24 +12,25 @@ dcmh <- sqrt(dcm1)
 dj <- diag(csums)
 di <- diag(rsums)
 tauden<-1 - sum(rsums^2)
-Apoly <- emerson.poly(mi, rsums)$B
+#Apoly <- emerson.poly(mi, rsums)$BT  #with trivial
+Apoly <- emerson.poly(mi, rsums)$B  #without trivial
 Apoly2 <- sqrt(di) %*% Apoly
 Bpoly <- emerson.poly(mj, csums)$B
 Bpoly2 <- sqrt(dj) %*% Bpoly
-pcc <- 1/sqrt(tauden)*(drmh %*% ( x - rsums %*% t(csums) ) %*% dcm1)
+#pcc <- 1/sqrt(tauden)*(drmh %*% ( x - rsums %*% t(csums) ) %*% dcm1)
+pcc <- (drmh %*% ( x - rsums %*% t(csums) ) %*% dcm1)
  Z <- t(Apoly2) %*% pcc %*% dj %*% Bpoly #no trivial
   pi <- (Apoly2) %*% Z %*% t(Bpoly2) #no trivial
 ZtZ<-Z%*%t(Z)   
  mu <- diag(ZtZ)
-tau<-sum(mu)
+#tau<-sum(mu)/tauden
 tZZ<-t(Z)%*%Z
     mu2<- diag(tZZ)
-r <- sum(mu > 1e-15)
+#r<-rmax
     Cweights <- dj
 #browser()
 donsca<- new("cabasicresults",
 RX=pcc,CX=t(pcc),Rweights=dj,Cweights=diag(rep(1,nrow(xo))),
-        Raxes=Bpoly,Caxes=Apoly2,r=r,mu=mu,mu2=mu2,catype="DONSCA",
-tau=tau,tauDen=tauden,Z=Z,ZtZ=ZtZ,tZZ=tZZ)
+        Raxes=Bpoly,Caxes=Apoly2,mu=mu,mu2=mu2,catype="DONSCA",tauDen=tauden,Z=Z,ZtZ=ZtZ,tZZ=tZZ)
 }
 
